@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: stream_buffer.c,v 1.5 1999/08/31 20:57:35 bazsi Exp $
+ * $Id: stream_buffer.c,v 1.6 2004/08/05 10:34:49 bazsi Exp $
  *
  ***************************************************************************/
  
@@ -193,8 +193,7 @@ static int do_flush(struct abstract_buffer *c, struct abstract_write *w)
 	UINT32 size;
 	int res;
 	
-	size = MIN(self->end - self->start,
-		self->block_size);
+	size = LIBOL_MIN(self->end - self->start, self->block_size);
                
 	res = A_WRITE(w, size, self->buffer + self->start);
 	if (res >= 0) {
